AzureStorage (AzureStorage v0.1.8)

Copy Markdown View Source

Azure Storage REST Client.

Before you can start interacting with Azure Storage services. You need to create a AzureStorage.Request.Context.

Example

iex> AzureStorage.create_blob_service("account_name", "account_key")
{:ok, %AzureStorage.Request.Context{}}

Summary

Functions

Create a new context to interact with Azure Blob Service

Create a new context to interact with Azure Fileshare service

Create a new context to interact with Azure Queue Storage

Create a new context to interact with Azure Table Storage Service

Functions

create_blob_service(account_name, account_key)

@spec create_blob_service(String.t(), String.t()) ::
  {:ok, AzureStorage.Request.Context.t()} | {:error, String.t()}

Create a new context to interact with Azure Blob Service

create_fileshare_service(account_name, account_key)

@spec create_fileshare_service(String.t(), String.t()) ::
  {:ok, AzureStorage.Request.Context.t()} | {:error, String.t()}

Create a new context to interact with Azure Fileshare service

create_queue_service(account_name, account_key)

@spec create_queue_service(String.t(), String.t()) ::
  {:ok, AzureStorage.Request.Context.t()} | {:error, String.t()}

Create a new context to interact with Azure Queue Storage

create_table_service(account_name, account_key)

@spec create_table_service(String.t(), String.t()) ::
  {:ok, AzureStorage.Request.Context.t()} | {:error, String.t()}

Create a new context to interact with Azure Table Storage Service